APIRequestInfo class

Available extensions

Constructors

APIRequestInfo({HTTPRequestMethod requestType = HTTPRequestMethod.get, Object? parameter, Map<String, String>? headers, List<UploadDocument> files = const [], required String url, String serviceName = "", int timeSecond = 90})

Properties

files List<UploadDocument>
getter/setter pair
getBody Object?

Available on APIRequestInfo, provided by the APIRequestInfoExtension extension

no setter
getParams Map<String, dynamic>?

Available on APIRequestInfo, provided by the APIRequestInfoExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
getter/setter pair
parameter Object?
getter/setter pair
requestType HTTPRequestMethod
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
getter/setter pair
timeSecond int
getter/setter pair
url String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited